==> open-cluster-management-cluster-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterDecisionFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterDecisionFluentImpl<A extends ClusterDecisionFluent<A>> extends BaseFluent<A> implements ClusterDecisionFluent<A>{
  public ClusterDecisionFluentImpl() {
  }
  public ClusterDecisionFluentImpl(ClusterDecision instance) {
    this.withClusterName(instance.getClusterName()); 
    this.withReason(instance.getReason()); 
  }
  private String clusterName;
  private String reason;
  public String getClusterName() {
    return this.clusterName;
  }
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  public Boolean hasClusterName() {
    return this.clusterName != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterDecisionFluentImpl that = (ClusterDecisionFluentImpl) o;
    if (clusterName != null ? !clusterName.equals(that.clusterName) :that.clusterName != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  reason,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterDecisionFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterDecisionFluentImpl<A extends ClusterDecisionFluent<A>> extends BaseFluent<A> implements ClusterDecisionFluent<A>{
  public ClusterDecisionFluentImpl() {
  }
  public ClusterDecisionFluentImpl(ClusterDecision instance) {
    if (instance != null) {
      this.withClusterName(instance.getClusterName());
      this.withReason(instance.getReason());
    }
  }
  private String clusterName;
  private String reason;
  public String getClusterName() {
    return this.clusterName;
  }
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  public Boolean hasClusterName() {
    return this.clusterName != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDecisionFluentImpl that = (ClusterDecisionFluentImpl) o;
    if (!java.util.Objects.equals(clusterName, that.clusterName)) return false;

    if (!java.util.Objects.equals(reason, that.reason)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  reason,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason); }
    sb.append("}");
    return sb.toString();
  }
  
}
